@@ -68,6 +68,11 @@ class Web(Tier):
                                                     help="Use GNU screen and open terminals on ALL machines added after a rolling deploy in %s tier" % self.tier)
         screen_parser.set_defaults(func=self.screen_new)
 
+        # Login - add --new argument
+        self.login_parser.add_argument("-z", "--zombies", dest="zombies",
+                                action="store_true", help="Login into a zombie node in %s" % (self.tier))
+        self.login_parser.set_defaults(func=self.web_login)
+
     def cli(self, args):
         knife = Knife()
         output = knife.ssh("ps -ef | egrep \"cli.py\" | grep -v \"sh -c\" | grep -v grep ",
@@ -153,3 +158,14 @@ class Web(Tier):
         p = Popen(" ".join(deploy_cmd), shell=True)
         retCode = p.wait()
         print "Return Code is: " + str(retCode)
+
+    def web_login(self, args):
+        if args.host is None:
+            knife_search = Knife()
+            if args.zombies:
+                list = knife_search.search(args.environment, self.tier, ["shutdown_gracefully:yes"])
+                args.host = list[0]
+            else:
+                list = knife_search.search(args.environment, self.tier, [" NOT shutdown_gracefully:yes"])
+                args.host = list[0]
+        self.login(args)
\ No newline at end of file
