@@ -92,7 +92,7 @@ class RollingDeploy
   def get_min_as_nodes
     return get_as.min_size
   end
-  
+
   def get_available_slots_per_node
     puts("Available Slots are: #{@available_slots}")
     return @available_slots if !@available_slots.nil?
@@ -104,7 +104,8 @@ class RollingDeploy
     end
     return @available_slots
   end
- 
+
+
   def get_busy_slots
     sth = @db_conn_handle.prepare("select count(*) from `delayed_jobs` WHERE (locked_by is NOT NULL AND locked_at > '#{DBI::Type::Timestamp.parse(Time.now.utc - 24 * 60 *60)}' AND failed_at IS NULL AND queue IN ('qpal_worker'))")
     sth.execute
@@ -148,15 +149,17 @@ class RollingDeploy
       
       if @instance_ip_map[i.id].nil?
         dns_name = nil
-        while dns_name.nil?
+        count = 3
+        while (dns_name.nil? && count > 0)
+          count = count - 1
           begin 
             dns_name = i.ec2_instance.dns_name
             break if !dns_name.nil?
-          rescue
+          rescue 
           end
           sleep 5
         end
-        @instance_ip_map[i.id] = dns_name
+        @instance_ip_map[i.id] = dns_name if (dns_name.nil? == false)
       end
     end
     return instances
